@@ -1,7 +1,6 @@
 import asyncio
 import importlib
 import json
-import logging
 import os
 import warnings
 from contextvars import ContextVar
@@ -23,12 +22,11 @@ from tortoise.fields.relational import (
     OneToOneFieldInstance,
 )
 from tortoise.filters import get_m2m_filters
-from tortoise.models import Model
+from tortoise.log import logger
+from tortoise.models import Model, ModelMeta
 from tortoise.transactions import current_transaction_map
 from tortoise.utils import generate_schema_for_client
 
-logger = logging.getLogger("tortoise")
-
 
 class Tortoise:
     apps: Dict[str, Dict[str, Type["Model"]]] = {}
@@ -642,7 +640,8 @@ class Tortoise:
     async def _reset_apps(cls) -> None:
         for app in cls.apps.values():
             for model in app.values():
-                model._meta.default_connection = None
+                if isinstance(model, ModelMeta):
+                    model._meta.default_connection = None
         cls.apps.clear()
         current_transaction_map.clear()
 
@@ -710,4 +709,4 @@ def run_async(coro: Coroutine) -> None:
         loop.run_until_complete(Tortoise.close_connections())
 
 
-__version__ = "0.17.5"
+__version__ = "0.17.7"
