@@ -511,6 +511,10 @@ class ModelMeta(type):
                 # For abstract classes
                 for key, value in meta.fields_map.items():
                     attrs[key] = value
+                # For abstract classes manager
+                for key, value in base.__dict__.items():
+                    if isinstance(value, Manager) and key not in attrs:
+                        attrs[key] = value.__class__()
             else:
                 # For mixin classes
                 for key, value in base.__dict__.items():
@@ -1332,6 +1336,7 @@ class Model(metaclass=ModelMeta):
             "description": cls._meta.table_description or None,
             "docstring": inspect.cleandoc(cls.__doc__ or "") or None,
             "unique_together": cls._meta.unique_together or [],
+            "indexes": cls._meta.indexes or [],
             "pk_field": cls._meta.fields_map[cls._meta.pk_attr].describe(serializable),
             "data_fields": [
                 field.describe(serializable)
